Documentation
¶
Overview ¶
LDA
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
K int // num topics
V int // num words
M int // num docs
N int // total word instances
Word []int // word n
Doc []int // doc ID for word n
Alpha []float64 // topic prior
Beta []float64 // word prior
Gamma float64 // regularization prior
}
data are the observations
func (*Model) FetchSimplices ¶
FetchmSimplices fetches simplices from the parameter slice. The parameter slice is advanced in place, hence a shallow copy of the slice must be passed.
Click to show internal directories.
Click to hide internal directories.